@@ -82,7 +82,7 @@ static struct vm_object *
 new_exception(struct vm_class *vmc, const char *message)
 {
 	struct vm_object *message_str;
-	struct vm_method *mb;
+	struct vm_method *vmm;
 	struct vm_object *obj;
 
 	obj = vm_object_alloc(vmc);
@@ -97,17 +97,25 @@ new_exception(struct vm_class *vmc, const char *message)
 			return rethrow_exception();
 	}
 
-	mb = vm_class_get_method(vmc, "<init>", "(Ljava/lang/String;)V");
-	if (!mb)
-		error("constructor not found");
+	vmm = vm_class_get_method(vmc, "<init>", "(Ljava/lang/String;)V");
+	if (vmm) {
+		vm_call_method(vmm, obj, message_str);
+
+		return obj;
+	}
+
+	vmm = vm_class_get_method(vmc, "<init>", "()V");
+	if (!vmm)
+		error("constructor not found for %s", vmc->name);
+
+	vm_call_method(vmm, obj);
 
-	vm_call_method(mb, obj, message_str);
 	return obj;
 }
 
 /**
  * signal_exception - used for signaling that exception has occurred
- *         in jato functions. Exception will be thrown when controll
+ *         in jato functions. Exception will be thrown when control
  *         is returned to JIT code.
  *
  * @exception: exception object to be thrown.
@@ -327,7 +335,7 @@ is_inside_unwind_unlock(struct compilation_unit *cu, unsigned char *ptr)
 
 /**
  * throw_from_jit - returns native pointer inside jitted method
- *                  that sould be executed to handle exception.
+ *                  that should be executed to handle exception.
  *                  This can be one of the following:
  *                        1) registered exception handler (catch/finally block)
  *                        2) method's unwind block (when no handler is found)
